        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==4 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==4 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==4 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==23 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==23 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==23 && cc==6){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==25 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==25 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==25 && cc==6){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==26 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==26 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==26 && cc==6){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==27 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==27 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==27 && cc==6){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 17 <br>5,8,12,16,18,20,23,27,28,32,33,35,38,39,45,47,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 11 <strong>control</strong><br>0,7,9,10,11,19,21,22,25,26,49';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>2,4,13,15,17,29,30,31,42,44';}
       if(rr==28 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 7 <br>1,3,14,40,43,46,48';}
       if(rr==28 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>6</strong> miembros: 4 <br>6,24,36,37';}
       if(rr==28 && cc==6){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260723 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>34</strong> miembros: 2 <br>34,41';}
}
